# Run tests

To run the tests:

```bash
# go to your component folder
cd placeholdername

# go to tests folder
cd tests

# install testing deps
pip install -r requirements.txt

# run tests
pytest .
```
